@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -126,58 +126,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created 2010-11-03 for Octave & Matlab
-## Updates:
-## 2010-12-19 Found that dom4j-1.6.1.jar is needed regardless of ML's dom4j
-##            presence in static classpath (ML r2007a)
-## 2011-01-04 Adapted for general checks, debugging & set up, both Octave & ML
-## 2011-04-04 Rebuilt into general setup/debug tool for spreadsheet I/O support
-##            and renamed chk_spreadsheet_support()
-## 2011-05-04 Added in UNO support (OpenOffice.org & clones)
-##     ''     Improved finding jar names in javaclasspath
-## 2011-05-07 Improved help text
-## 2011-05-15 Better error msg if OOo instal dir isn't found
-## 2011-05-20 Attempt to cope with case variations in subdir names of OOo install dir (_get_dir_)
-## 2011-05-27 Fix proper return value (retval); header text improved
-## 2011-05-29 Made retval value dependent on detected interfaces & adapted help text
-## 2011-06-06 Fix for javaclasspath format in *nix w. octave-java-1.2.8 pkg
-##     ''     Fixed wrong return value update when adding UNO classes
-## 2011-09-03 Small fix to better detect Basis* subdir when searching unoil.jar
-## 2011-09-18 Fixed 'Matlab style short circuit' warning in L. 152
-## 2012-12-24 Amended code stanza to find unoil.jar; now works in LibreOffice 3.5b2 as well
-## 2012-06-07 Replaced all tabs by double space
-## 2012-06-24 Replaced error msg by printf & return
-##     ''     Added Java pkg inquiry (Octave) before attempting javaclasspath()
-##     ''     Updated check for odfdom version (now supports 0.8.8)
-## 2012-10-07 Moved common classpath entry code to private function
-## 2012-12-21 POI 3.9 support (w. either xmlbeans.jar or xbeans.jar)
-## 2013-01-16 Updated to Octave w built-in Java (3.7.1+)
-## 2013-06-23 More informative error messages:
-##     ''     COM section: only called on Windows
-##     ''     Java section: first check for Java support in Octave
-##     ''     Restyled into Octave conventions
-## 2013-07-18 Add Fedora naming scheme to POI jar entries (the "old" ones are symlinks)
-## 2013-08-12 More restyling
-##     ''     odfdom 0.8.9 support (incubator-0.6) - alas that is buggy :-(  => dropped
-##     ''     Removed all Matlab-specific code
-## 2013-08-19 Fixed wrong reference to path_to_jars where path_to_ooo was intended
-##     ''     Fixed wrong echo of argument nr in checks on path_to_ooo
-## 2013-08-20 Allow subdir searches for Java class libs
-## 2013-09-01 Adapt recursive file search proc name (now rfsearch.m)
-## 2013-12-14 Texinfo header updated to OCT
-## 2013-12-20 More Texinfo header improvements
-## 2013-12-28 Added check for OpenXLS version 10
-## 2013-12-29 Added gwt-servlet-deps.jar to OpenXLS dependencies
-## 2014-01-07 Style fixes; "forward slash expected" message conditional on dbug
-## 2014-01-08 Keep track of loaded jars; allow unloading them; return them as output arg
-##     ''     Return checked interfaces; update texinfo header
-## 2014-01-17 Tame messages about COM/ActiveX if dbug = 0
-## 2014-04-06 Skip unojarpath search for UNO entries 4 and up; code style fixes
-## 2014-04-14 Updated texinfo header & OCT r/w support messages
-## 2014-04-15 More updates to texinfo header
-## 2014-04-26 Check for built-in Java support before trying to handle Java stuff
-##     ''     Cleaned up various messages
-## 2014-10-31 Move common code w. xlsopen/odsopen into private functions
-## 2014-11-02 Fix syntax error when adding UNO programdir to loaded_jars
 
 function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_to_jars, dbug, path_to_ooo)
 
@@ -496,6 +444,12 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
     ## 2. Find where URE is located. Watch out because
     ##    case of ./ure is unknown
     uredir = get_dir_ (path_to_ooo, "ure");
+    new_lo = 0;
+    if (isempty (uredir))
+      ## In newer LO, java jars live in <path_to_ooo>/program/classes
+      uredir = get_dir_ ([path_to_ooo filesep "program"], "classes");
+      new_lo = 1;
+    endif
     if (isempty (uredir))
       if (dbug > 1)
         warning ("Wrong path to OOo/LO, or incomplete OOo/LO installation\n");
@@ -504,13 +458,18 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
     endif
 
     ## 3. Most jars live in ./ure/share/java or ./ure/java. Construct unojarpath
-    unojardir = get_dir_ (uredir, "share");
-    if (isempty (unojardir))
-      tmp = uredir;
+    if (new_lo)
+      ## Newer LO version? <LO>/progam/classes has no "java" subdir
+      unojarpath = uredir;
     else
-      tmp = unojardir;
+      unojardir = get_dir_ (uredir, "share");
+      if (isempty (unojardir))
+        tmp = uredir;
+      else
+        tmp = unojardir;
+      endif
+      unojarpath = get_dir_ (tmp, "java");
     endif
-    unojarpath = get_dir_ (tmp, "java");
 
     ## 4. Now search for UNO jars. There may be two special cases A. and B.
     for ii=1:numel (missing0)
@@ -548,7 +507,12 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
 
       else
         ## Rest of missing UNO entries
-        if (strcmpi (missing0{ii}, "unoil"))
+        if (new_lo)
+          ## Search in <LO>/program/classes
+          sfile = dir ([unojarpath filesep missing0{ii} "*"]);
+          jfile = [unojarpath filesep sfile.name];
+
+        elseif (strcmpi (missing0{ii}, "unoil"))
           ## B. Special case as unoil.jar usually resides in
           ##    ./Basis<something>/program/classes
           ##    Find out the exact name of Basis.....
