@@ -48,7 +48,10 @@
 ## If @var{range} is omitted or just the top left cell of the range is
 ## specified, the actual range to be used is determined by the size of
 ## @var{arr}.  If nothing is specified for @var{range} the top left cell
-## is assumed to be 'A1'.
+## is assumed to be 'A1'.  If defined in the spreadsheet file, a "Named
+## range" can also be specified.  In that case @var{wsh} will be ignored
+## and the worksheet associated with the specified Named range will be
+## used.
 ##
 ## Data are added to the worksheet, ignoring other data already present;
 ## existing data in the range to be used will be overwritten.
@@ -88,39 +91,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users sf net>
 ## Created: 2009-12-01
-## Updates: 
-## 2010-01-03 (OOXML support / POI)
-## 2010-03-14 Updated help text section on Java memory usage
-## 2010-07-27 Added formula writing support (based on patch by Benjamin Lindner)
-## 2010-08-01 Added check on input array size vs. spreadsheet capacity
-##     ''     Changed argument topleft into range (now compatible with ML); the
-##     ''     old argument version (just topleft cell) is still recognized, though
-## 2010-08014 Added char array conversion to 1x1 cell for character input arrays
-## 2010-08-16 Added check on presence of output argument. Made wsh = 1 default
-## 2010-08-17 Corrected texinfo ("topleft" => "range")
-## 2010-08-25 Improved help text (section on java memory usage)
-## 2010-11-12 Moved ptr struct check into main func. More input validity checks
-## 2010-11-13 Added check for 2-D input array
-## 2010-12-01 Better check on file pointer struct (ischar (xls.xtype))
-## 2011-03-29 OpenXLS support added. Works but saving to file (xlsclose) doesn't
-##            work yet 
-##      ''    Bug fixes (stray variable c_arr, wrong test for valid xls struct)
-## 2011-05-18 Experimental UNO support
-## 2011-09-08 Bug fix in range arg check; code cleanup
-## 2011-11-18 Fixed another bug in test for range parameter being character string
-## 2012-01-26 Fixed "seealso" help string
-## 2012-02-20 Fixed range parameter to be default empty string rather than
-##            empty numeral
-## 2012-02-27 More range param fixes
-## 2012-03-07 Updated texinfo help text
-## 2012-05-22 Cast all numeric data in input array to double
-## 2012-10-12 Moved all interface-specific subfubcs into ./private
-## 2012-10-24 Style fixes
-## 2012-12-18 Improved error/warning messages
-## 2012-12-29 Style fixes
-## 2014-01-29 Allow OCT write support for OOXML & ODS & gnumeric
-## 2015-03-06 Texinfo header update
-##     ''     "\n" augmented to error messages to suppress traceback
 
 function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
 
@@ -166,6 +136,28 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
     error ("oct2xls: character string expected for arg # 4 (range)\n");
   elseif (isempty (crange))
     crange = "";
+  else
+    ## FIXME the following stanza can be made into a separate func
+    ## Check for range name and convert it to range & optionally sheet
+    ## 1. Check if it matches a range
+    mtch = cell2mat (regexp (crange, ...
+                     '(^[A-Za-z]+[0-9]+){1}(:[A-Za-z]+[0-9]+$)?', "tokens"));
+    if (! isempty (mtch) && ! strcmp ([mtch{:}], crange))
+      ## Apparently not a range. Try range names
+      if (! isfield (xls, "nmranges"))
+        xls.nmranges = getnmranges (xls);
+      endif
+      idx = strmatch (crange, xls.nmranges(:, 1));
+      if (isempty (idx))
+        error ("oct2xls: no range '%s' in workbook", crange);
+      else
+        ## Get range and -optionally- sheet it refers to
+        crange = xls.nmranges{idx, 3};
+        if (! isempty (xls.nmranges{idx, 2}))
+          wsh = xls.nmranges{idx, 2};
+        endif
+      endif
+    endif
   endif
 
   ## Various options 
