@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -16,6 +16,7 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} [@var{filetype}] = odsfinfo (@var{filename} [, @var{reqintf}])
 ## @deftypefnx {Function File} [@var{filetype}, @var{sh_names}] = odsfinfo (@var{filename} [, @var{reqintf}])
+## @deftypefnx {Function File} [@var{filetype}, @var{sh_names}, @var{nmranges}] = odsfinfo (@var{filename} [, @var{reqintf}])
 ## Query an OpenOffice_org or Gnumeric spreadsheet file @var{filename}
 ## (with ods or gnumeric suffix) for some info about its contents.
 ##
@@ -28,10 +29,16 @@
 ## array) of sheet names contained in @var{filename}, in the order (from left
 ## to right) in which they occur in the sheet stack.
 ##
+## Optional return argument @var{nmranges} returns a list of Named ranges
+## defined in the spreadsheet, if any.
+##
 ## If you omit return arguments @var{filetype} and @var{sh_names} altogether,
 ## odsfinfo returns the sheet names and for each sheet the actual occupied
-## data ranges to the screen.The occupied cell range will have to be
-## determined behind the scenes first; this can take some time.
+## data ranges to the screen.  The occupied cell range will have to be
+## determined behind the scenes first; this can take some time.  If any
+## Named ranges are defined in the spreadsheet file, they will be listed
+## on the screen as well.  Named ranges work only for the OCT interface,
+## with the UNO interface it doesn't work for .ods files.
 ## 
 ## odsfinfo execution can take its time for large spreadsheets as the entire
 ## spreadsheet has to be parsed to get the sheet names, let alone exploring
@@ -60,30 +67,6 @@
 
 ## Author: Philip Nienhuis <pr.nienhuis at users.sf.net>
 ## Created: 2009-12-17
-## Updates:
-## 2010-01-03 Added functionality for JOD as well
-## 2010-03-03 Fixed echo of proper number of occupied data rows
-## 2010-03-18 Fixed proper echo of occupied data range 
-##            (ah those pesky table-row-repeated & table-column-repeated attr.... :-( )
-## 2010-03-18 Separated range exploration (for OTK only yet) in separate function file
-## 2010-03-20 "Beautified" output (for OTK ), used range now in more tabular form
-## 2010-05-23 Updated jOpenDocument support (can also get occupied data range now)
-## 2010-05-31 Added remark about delays when determining occupied data range
-## 2011-03-23 Adapted to odfdom 0.8.7 (changed getXPath method call)
-## 2011-05-07 Experimental UNO support added
-## 2011-09-03 Normal return in case of no ODS support (empty ods struct)
-## 2012-01-26 Fixed "seealso" help string
-## 2012-02-25 Return occupied sheet ranges in output args
-##     ''     Improve echo of sheet names & ranges if interactive
-## 2012-03-01 Fix wrong cell refs in UNO section ("(..)" rather than "{..}"
-## 2012-06-08 Support for odfdom-0.8.8-incubator
-## 2012-10-12 Moved all interface-specific code into ./private subfuncs
-## 2012-10-24 Style fixes
-## 2013-09-09 Native Octave interface ("OCT") for reading
-## 2013-09-23 Header updated to OCT interface
-## 2013-12-01 Output arg #2 adapted to file type tru switch stmt
-## 2014-04-27 Fix switch (period before extension)
-##     ''     Style fixes
 
 function [ filetype, sh_names ] = odsfinfo (filename, reqintf=[])
 
@@ -142,6 +125,21 @@ function [ filetype, sh_names ] = odsfinfo (filename, reqintf=[])
       endif
       printf ("%s%s%s\n", str1, str2(1:lstr2-length (sh_names{ii, 1})), str3);
     endfor
+    ## Echo named ranges
+    nmranges = getnmranges (ods);
+    snmr = size (nmranges, 1);
+    if(snmr > 0)
+      ## Find max length of entries
+      nmrl = min (35, max ([cellfun("length", nmranges(:, 1)); 10]));
+      shtl = min (31, max ([cellfun("length", nmranges(:, 2)); 6]));
+      rnml = max ([cellfun("length", nmranges(:, 3)); 5]);
+      frmt = sprintf ("%%%ds  %%%ds  %%%ds\n" , nmrl, shtl, rnml);
+      printf (["\n" frmt], "Range name", "Sheet", "Range");
+      printf (frmt, "----------", "-----", "-----" );
+      for ii=1:size (nmranges, 1)
+        printf (frmt, nmranges(ii, 1:3){:});
+      endfor
+    endif
   endif
 
   ods = odsclose (ods);
