@@ -44,49 +44,7 @@
 
 ## Author: Markus Bergholz <markuman at gmail.com>
 ## Amended by Philip Nienhuis <prnienhuis at users.sf.net>
-## ToDo
-## - use english language as default (atm it's all german. "Tabelle1" instead of "Table1").
-## - fix write to defined range (rows still starts a row 1)
-## - write more than 3 worksheets
-## - date and boolean type
-## - write cell (numeric and string mixed)
-## - open/add/edit/manipulate an existing xlsx file
-## - improve mex file
-
-## ChangeLog
-## 2014/01/24		- include to io package
-##			        - add write to defined range/position (offset). Works for colums,
-##                not for rows!
-## 2014/01/20		- remove 702 column limit
-##           		- write mex file to bypass the bottleneck (still exists because 
-##                mex file calls a script file! now ~230sec for 1000x1000 matrix. before ~410sec)
-## 2014/01/17		- include __OCT_cc__ instead of __number_to_alphabetic
-##           		- fix/improve zip behavior
-## 2013/11/23		- prepare xlswrite for handling existing files
-##           		- take care for excel limitations (maybe tbc)
-## 2013/11/17		- user can write to another worksheet. limited to index 1, 2 or 3 atm
-##           		- user can name the worksheets by string. automatically written to sheetid 1.
-##           		- user can define name+index at the same time {2,'wsh name'} e.g.
-## 2013/11/16		- relationshiptypes validation fix
-## Version 0.1
 ## 2013/11/08		- Initial Release
-## 2014-04-26   - Replace __OCT_cc__ by binary __num2char__
-##     ''       - Fix wrong file handle refs when rewriting app.xml
-## 2014-08-25   - (PRN) __num2char__ -> num2col (mex->oct) because mex cannot be compiled
-##                on 64-bit MingW systems due to int64_t errors (c-compiler issue?)
-## 2014-10-04   - Make sure searched worksheet names matches exactly (bug # 43353)
-## 2014-10-05   - (PRN) polish worksheet bookkeeping when adding sheets (bug #43354)
-## 2014-10-08   - Fix worksheet bookkeeping in _rels an .rels
-## 2014-10-10   - More robust code for reading entries from SharedStrings.xml in
-##                __OCT_oct2xlsx_sh__ (ignore <t> attributes)
-## 2014-10-26   - Improve rId bookkeeping in _rels
-## 2014-10-29   - more _rels bookkeepin improvements.
-##              - Ignore writing empty text cells to worksheet
-## 2015-03-07   - Replace deprecated strmatch
-## 2015-07-10   - Fix typo in duplicate worksheet names check (bug #45498)
-##    ''        - Change numeric write format to %0.15g (MS-Excel accepts that)
-##                to ensure 15 digits precision. Along the way aliminate
-##                expensive call to strtrim()
 
 function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_opts, obj_dims)
 
@@ -139,12 +97,6 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
     endif
   endif
 
-# if (spsh_opts.formulas_as_text == 0)
-    ## Provisionally only read/write strings, not formulas
-    ## FIXME actually a formula evaluator is required to process formulas
-#   spsh_opts.formulas_as_text = 1;
-# endif
-
   if (new_sh)
     rawarr = {};
     lims = [];
@@ -157,57 +109,17 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
   ## Merge old and new data. Provisionally allow empty new data to wipe old data
   [rawarr, lims, onr, onc] = __OCT_merge_data__ (rawarr, lims, arrdat, obj_dims, spsh_opts);
 
-## FIXME - contains stuff that won't work with existing sheets
-##         (though I like the idea PRN)
-%## something cool, that matlab doesn't support
-%# xlswrite('myfile.xlsx',arrdat,{'1','Sheetname'})
-%if (iscell (wsh))
-%  # check size
-%  if (1 ~= rows (wsh) || 2 ~= columns (wsh))
-%    error ("Too many input arguments for wsh");
-%  endif
-%  # check first argument
-%  if (1 == ischar (wsh{1,1}))
-%    if (31 < length (wsh{1,1}))
-%      error ("Worksheet name longer than 31 characters is not supported by Excel");
-%    endif
-%    wsh_string=wsh{1,1};
-%  elseif (isnumeric (wsh{1,1}))
-%    if (1 ~= ismember (wsh{1,1} ,1:3))
-%      error ("wsh index must be 1, 2 or 3");
-%    endif
-%    wsh_number = wsh{1,1};
-%  else
-%    error ("wsh should contain one numeric value (for indexing) and one string (for naming)");
-%  endif
-%  
-%  # check second argument
-%  if (ischar (wsh{1,2}))
-%    if (31 < length(wsh{1,2}))
-%      error ("Worksheet name longer than 31 characters is not supported by Excel");
-%    endif 
-%    wsh_string = wsh{1,2};
-%  elseif (isnumeric (wsh{1,2}))
-%    if (! ismember (wsh{1,2} ,1:3))
-%      error ("wsh index must be 1, 2 or 3");
-%    endif
-%    wsh_number = wsh{1,2};
-%  else
-%    error ("wsh should contain one numeric value (for indexing) and one string (for naming)");
-%  endif
-%endif
-
-## What needs to be done:
-## - Find out worksheet number (easy, wsh_number). Relates 1:1 to rId
-## - Write data to <temp>/xl/worksheets/sheet<wsh_number>.xml
-##   * For each string, check (persistent var) if sharedStrings.xml exists
-##     > If not, create it.
-##   * For each string check if it is in <temp>/sharedStrings.xml
-##     > if YES, put pointer in new worksheet
-##     > if NO, add node in sharedStrings.xml and pointer in new worksheet
-## - If needed (new file) update <temp>/workbook.xml w. sheet name & sheetId
-##   higher than any existing sheetId
-## - Update workbook.xml.rels
+  ## What needs to be done:
+  ## - Find out worksheet number (easy, wsh_number). Relates 1:1 to rId
+  ## - Write data to <temp>/xl/worksheets/sheet<wsh_number>.xml
+  ##   * For each string, check (persistent var) if sharedStrings.xml exists
+  ##     > If not, create it.
+  ##   * For each string check if it is in <temp>/sharedStrings.xml
+  ##     > if YES, put pointer in new worksheet
+  ##     > if NO, add node in sharedStrings.xml and pointer in new worksheet
+  ## - If needed (new file) update <temp>/workbook.xml w. sheet name & sheetId
+  ##   higher than any existing sheetId
+  ## - Update workbook.xml.rels
 
   ## Write data to worksheet file. If status > 1, new sharedStrings file entries are required
   [xls, status]  = __OCT_oct2xlsx_sh__ (xls, wsh_number, rawarr, lims, onc, onr, spsh_opts);
@@ -242,7 +154,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
       shnum = max (sheetids) + 1;
       wshtag = sprintf ('<sheet name="%s" sheetId="%d" r:id="rId%d" />', ...
                         wsh_string, shnum, nwrId);
-      sheets = strrep (sheets, "/></sheets>", ["/>" wshtag "</sheets>"]);
+      sheets = regexprep (sheets, '/>\s*</sheets>', ["/>" wshtag "</sheets>"]);
       xls.sheets.sheetid(end+1) = shnum;
     endif
     ## Re(/over-)write workbook.xml; start at sheets node
@@ -325,7 +237,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
       nshts = str2double (getxmlattv (vt2, "size")) + 1;
       vt2 = regexprep (vt2, 'size="(\d+)"', ['size="' sprintf("%d", nshts) '"']);
       ## Add new worksheet entry
-      vt2 = strrep (vt2, "</vt:lpstr></vt:vector>", ["</vt:lpstr>" wshnode "</vt:vector>"]);
+      vt2 = regexprep (vt2, "</vt:lpstr>\s*</vt:vector>", ["</vt:lpstr>" wshnode "</vt:vector>"]);
       vt = [vt1 vt2];
     endif
     ## Re(/over-)write apps.xml
@@ -348,7 +260,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
       rId = str2double (cell2mat (regexp (rxml, 'Id="rId(\d+)"', "tokens")));
       nwrId = sort (rId)(end) + 1;
       entry = sprintf ('<Relationship Id="rId%d" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/sharedStrings" Target="sharedStrings.xml"/>', nwrId);
-      rxml = strrep (rxml, "/></Relationships>", ["/>" entry "</Relationships>"]);
+      rxml = regexprep (rxml, '/>\s*</Relationships>', ["/>" entry "</Relationships>"]);
       rid = fopen ([xls.workbook filesep "xl" filesep "_rels" filesep "workbook.xml.rels"], "w");
       fprintf (rid, "%s", rxml);
       fclose (rid);
@@ -386,6 +298,12 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh=1, crange="", spsh_
   [modf, ia, ib] = getxmlnode (cxml, "dcterms:created", [], 1);
   cxml = [cxml(1:ia-1) strrep(cxml(ia:ib), modf, modtime) cxml(ib+1:end)];
   [modf, ia, ib] = getxmlnode (cxml, "dcterms:modified", [], 1);
+  ## Possible LO bug (see Octave bug #45915) - "dcterms:modified" node may lack
+  if (isempty (modf))
+    ia = ib = index (cxml, "<cp:revision>");
+    cxml = [ cxml(1:ia-1) '<dcterms:modified xsi:type="dcterms:W3CDTF">2015-09-10T19:53:40Z</dcterms:modified><' cxml(ib+1:end) ];
+    [modf, ia, ib] = getxmlnode (cxml, "dcterms:modified", [], 1);
+  endif
   cxml = [cxml(1:ia-1) strrep(cxml(ia:ib), modf, modtime) cxml(ib+1:end)];
   cid = fopen ([xls.workbook filesep "docProps" filesep "core.xml"], "w+");
   fprintf (cid, "%s", cxml);
