@@ -36,47 +36,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2009-12-27
-## Updates:
-## 2010-01-14 (yeah what was it...>
-## 2010-01-17 Make sure proper dimensions are checked in parsed javaclasspath
-## 2010-04-11 Introduced check on odfdom.jar version - only 0.7.5 works properly
-## 2010-06-02 Moved in check on JOD version
-## 2010-06-05 Experimental odfdom 0.8.5 support
-## 2010-06-## dropped 0.8.5, too buggy
-## 2010-08-22 Experimental odfdom 0.8.6 support
-## 2010-08-23 Added odfvsn (odfdom version string) to output struct argument
-##     ''     Bugfix: moved JOD version check to main function (it can't work here)
-##     ''     Finalized odfdom 0.8.6 support (even prefered version now)
-## 2010-09-11 Somewhat clarified messages about missing java classes
-##     ''     Rearranged code a bit; fixed typos in OTK detection code (odfdvsn -> odfvsn)
-## 2010-09-27 More code cleanup
-## 2010-11-12 Warning added about waning support for odfdom v. 0.7.5
-## 2011-05-06 Fixed wrong strfind tests
-##     ''     Experimental UNO support added
-## 2011-05-18 Forgot to initialize odsinterfaces.UNO
-## 2011-06-06 Fix for javaclasspath format in *nix w. java-1.2.8 pkg
-##     ''     Implemented more rigid Java check
-##     ''     Tamed down verbosity
-## 2011-09-03 Fixed order of odsinterfaces.<member> statement in Java detection try-catch
-##     ''     Reset tmp1 (always allow interface rediscovery) for empty odsinterfaces arg
-## 2011-09-18 Added temporary warning about UNO interface
-## 2012-03-22 Improved Java checks (analogous to xlsopen)
-## 2012-06-06 Again improved & simplified Java-based interface checking support
-## 2012-06-08 Support for odfdom-0.8.8 (-incubator)
-## 2012-10-07 Moved common classpath entry code to ./private function
-## 2012-10-07 Moved into ./private
-## 2012-10-24 Style fixes
-## 2013-03-01 active -> default interface
-##     ''     Moved check for Java support to separate file in private/
-##     ''     Fixed javaclasspath info resync in case of requested interfaces
-## 2013-08-13 Tested odfdom 0.8.9 (odfdom-0.6-incubator); found it doesn't work :-(
-## 2013-09-09 Native Octave interface ("OCT")for reading
-## 2013-09-11 Check Java again when requesting a specific Java interface
-## 2013-09-29 Treat OCT as any other interface
-## 2013-12-06 Updated copyright strings; style fixes
-## 2013-12-20 java_invoke -> javaMethod
-## 2014-04-24 Skip all Java checks if Octave was built w/o Java support
-## 2015-03-07 Improve regexp to extract odfdom version
 
 function [odsinterfaces] = getodsinterfaces (odsinterfaces)
 
