@@ -20,7 +20,7 @@
 ## @deftypefnx {Function File} [ @var{rawarr}, @var{xls}, @var{rstatus} ] = xls2oct (@var{xls}, @var{wsh}, @var{range}, @var{options})
 ##
 ## Read data contained within cell range @var{range} from worksheet @var{wsh}
-## in an Excel spreadsheet file pointed to in struct @var{xls}. Gnumeric
+## in an Excel spreadsheet file pointed to in struct @var{xls}; Gnumeric
 ## files can be read as well.
 ##
 ## @var{xls} is supposed to have been created earlier by xlsopen in the
@@ -30,32 +30,35 @@
 ## case-sensitive and it may be max. 31 characters long.
 ## Note that in case of a numerical @var{wsh} this number refers to the
 ## position in the worksheet stack, counted from the left in an Excel
-## window. The default is numerical 1, i.e. corresponding to the leftmost
+## window.  The default is numerical 1, i.e. corresponding to the leftmost
 ## worksheet tab in the Excel file.
 ##
-## @var{range} is expected to be a regular spreadsheet range format,
-## or "" (empty string, indicating all data in a worksheet).
+## @var{range} is expected to be either a regular spreadsheet range
+## format, "" (empty string, indicating all data in a worksheet), or a
+## "Named range" defined in the spreadsheet file.  In case of a Named
+## range, the worksheet associated with that Named range will be used
+## instead of the one specified in @var{wsh}.
 ## If no range is specified the occupied cell range will have to be
 ## determined behind the scenes first; this can take some time for the
-## Java-based interfaces. Be aware that in COM/ActiveX interface the
-## used range can be outdated. The Java-based interfaces are more 
+## Java-based interfaces.  Be aware that in COM/ActiveX interface the
+## used range can be outdated.  The Java-based interfaces are more 
 ## reliable in this respect albeit much slower.
 ##
 ## Optional argument @var{options}, a structure, can be used to
 ## specify various read modes by setting option fields in the struct
-## to true (1) or false (0). Currently recognized option fields are:
+## to true (1) or false (0).  Currently recognized option fields are:
 ##
 ## @table @asis
 ## @item "formulas_as_text"
 ## If set to TRUE or 1, spreadsheet formulas (if at all present)
 ## are read as formula strings rather than the evaluated formula
-## result values. The default value is 0 (FALSE).
+## result values.  The default value is 0 (FALSE).
 ##
 ## @item 'strip_array'
 ## Set the value of this field set to TRUE or 1 to strip the returned
 ## output array @var{rawarr} from empty outer columns and rows. The
 ## spreadsheet cell rectangle limits from where the data actually
-## came will be updated. The default value is FALSE or 0 (no cropping).
+## came will be updated.  The default value is FALSE or 0 (no cropping).
 ## When using the COM interface, the output array is always cropped.
 ## @end table
 ##
@@ -64,7 +67,7 @@
 ## worksheet (as if a range of @'' (empty string) was specified).
 ## 
 ## If only two arguments are specified, xls2oct assumes the second
-## argument to be @var{wsh}. In that case xls2oct will try to read
+## argument to be @var{wsh}.  In that case xls2oct will try to read
 ## all data contained in that worksheet.
 ##
 ## Return argument @var{rawarr} contains the raw spreadsheet cell data.
@@ -86,7 +89,7 @@
 ## so any returned cell array may turn out to be smaller than requested
 ## in @var{range}, independent of field 'formulas_as_text' in @var{options}.
 ## When using COM, POI, or UNO interface, formulas in cells are evaluated; if
-## that fails cached values are retrieved. These may be outdated depending
+## that fails cached values are retrieved.  These may be outdated depending
 ## on Excel's "Automatic calculation" settings when the spreadsheet was saved.
 ##
 ## When reading from merged cells, all array elements NOT corresponding 
@@ -115,36 +118,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2010-10-16
-## Updates: 
-## 2009-01-03 (added OOXML support & cleaned up code. Excel 
-##             ADDRESS function still not implemented in Apache POI)
-## 2010-03-14 Updated help text
-## 2010-05-31 Updated help text (delay i.c.o. empty range due to getusedrange call)
-## 2010-07-28 Added option to read formulas as text strings rather than evaluated value
-## 2010-08-25 Small typo in help text
-## 2010-10-20 Added option fornot stripping output arrays
-## 2010-11-07 More rigorous input checks. 
-## 2010-11-12 Moved pointer check into main func
-## 2010-11-13 Catch empty sheets when no range was specified
-## 2011-03-26 OpenXLS support added
-## 2011-03-29 Test for proper input xls struct extended
-## 2011-05-18 Experimental UNO support added
-## 2011-09-08 Minor code layout
-## 2012-01-26 Fixed "seealso" help string
-## 2012-02-25 Fixed missing quotes in struct check L.149-153
-## 2012-02-26 Updated texinfo header help text
-## 2012-06-06 Implemented "formulas_as_text" option for COM
-## 2012-06-07 Replaced all tabs by double space
-## 2012-10-12 Moved all interface-specific subfubcs into ./private
-## 2012-10-24 Style fixes
-## 2013-09-30 Native Octave (OCT) added
-## 2013-10-01 Some adaptations for gnumeric
-## 2013-10-02 Delete ODS section
-## 2013-11-02 Added rstatus return arg for __OCT_xlsx2oct__.m
-## 2013-11-08 Added spsh_opts arg for __OCT_xls2oct__.m
-## 2014-02-08 Style fixes
-## 2015-03-06 Texinfo header update
-##     ''     "\n" suffix to error messages to suppress traceback
 
 function [ rawarr, xls, rstatus ] = xls2oct (xls, wsh=1, datrange="", spsh_opts=[])
 
@@ -165,9 +138,32 @@ function [ rawarr, xls, rstatus ] = xls2oct (xls, wsh=1, datrange="", spsh_opts=
   if (~(ischar (wsh) || isnumeric (wsh)))
     error ("Integer (index) or text (wsh name) expected for arg # 2\n");
   endif
+
   ## Check range
   if (~(isempty (datrange) || ischar (datrange)))
     error ("Character string expected for arg # 3 (range)\n"); 
+  else
+    ## FIXME the following stanza can be made into a separate func
+    ## Check for range name and convert it to range & optionally sheet
+    ## 1. Check if it matches a range
+    mtch = cell2mat (regexp (datrange, ...
+                     '(^[A-Za-z]+[0-9]+){1}(:[A-Za-z]+[0-9]+$)?', "tokens"));
+    if (! isempty (mtch) && ! strcmp ([mtch{:}], datrange))
+      ## Apparently not a range. Try range names
+      if (! isfield (xls, "nmranges"))
+        xls.nmranges = getnmranges (xls);
+      endif
+      idx = strmatch (datrange, xls.nmranges(:, 1));
+      if (isempty (idx))
+        error ("oct2xls: no range '%s' in workbook", crange);
+      else
+        ## Get range and -optionally- sheet it refers to
+        datrange = xls.nmranges{idx, 3};
+        if (! isempty (xls.nmranges{idx, 2}))
+          wsh = xls.nmranges{idx, 2};
+        endif
+      endif
+    endif
   endif
 
   ## Check & setup options struct
@@ -211,6 +207,10 @@ function [ rawarr, xls, rstatus ] = xls2oct (xls, wsh=1, datrange="", spsh_opts=
       [rawarr, xls, rstatus] = __OCT_xlsx2oct__ (xls, wsh, datrange, spsh_opts);
     elseif (strcmpi (xls.app, 'gnumeric'))
       [rawarr, xls, rstatus] = __OCT_gnm2oct__ (xls, wsh, datrange);
+    elseif (strcmpi (xls.app, 'ods'))
+      [rawarr, xls, rstatus] = __OCT_ods2oct__ (xls, wsh, datrange, spsh_opts);
+    else
+      error ("xls2oct.m: file format not supported for OCT interface\n");
     endif
   ##elseif ---- <Other interfaces here>
     ## Call to next interface
